(function() {
    var B = {
        "B33194": {
            "description": "[SIM] Space consistency", 
            "unit": "%"
        }, 
        "B33195": {
            "description": "[SIM] MeteoDB variable ID", 
            "unit": "NUMERIC"
        }, 
        "B33196": {
            "description": "[SIM] Data has been invalidated", 
            "unit": "CODE TABLE 33196"
        }, 
        "B33197": {
            "description": "[SIM] Manual replacement in substitution", 
            "unit": "CODE TABLE 33197"
        }, 
        "B33192": {
            "description": "[SIM] Climatological and consistency check", 
            "unit": "%"
        }, 
        "B33193": {
            "description": "[SIM] Time consistency", 
            "unit": "%"
        }, 
        "B11002": {
            "description": "WIND SPEED", 
            "unit": "M/S"
        }, 
        "B11003": {
            "description": "U-COMPONENT", 
            "unit": "M/S"
        }, 
        "B11001": {
            "description": "WIND DIRECTION", 
            "unit": "DEGREE TRUE"
        }, 
        "B11006": {
            "description": "W-COMPONENT", 
            "unit": "M/S"
        }, 
        "B33050": {
            "description": "GLOBAL GTSPP QUALITY FLAG", 
            "unit": "CODE TABLE 33050"
        }, 
        "B11004": {
            "description": "V-COMPONENT", 
            "unit": "M/S"
        }, 
        "B11005": {
            "description": "W-COMPONENT", 
            "unit": "PA/S"
        }, 
        "B14018": {
            "description": "INSTANTANEOUS SHORT-WAVE RADIATION (incoming)", 
            "unit": "W/M**2"
        }, 
        "B14019": {
            "description": "SURFACE ALBEDO", 
            "unit": "%"
        }, 
        "B14016": {
            "description": "NET RADIATION", 
            "unit": "J/M**2"
        }, 
        "B14017": {
            "description": "INSTANTANEOUS LONG-WAVE RADIATION (incoming)", 
            "unit": "W/M**2"
        }, 
        "B33198": {
            "description": "[SIM] Observation increment", 
            "unit": "NUMERIC"
        }, 
        "B07002": {
            "description": "HEIGHT OR ALTITUDE", 
            "unit": "M"
        }, 
        "B07004": {
            "description": "PRESSURE", 
            "unit": "PA"
        }, 
        "B07007": {
            "description": "HEIGHT", 
            "unit": "M"
        }, 
        "B31000": {
            "description": "SHORT DELAYED DESCRIPTOR REPLICATION FACTOR", 
            "unit": "NUMERIC"
        }, 
        "B31001": {
            "description": "DELAYED DESCRIPTOR REPLICATION FACTOR", 
            "unit": "NUMERIC"
        }, 
        "B31002": {
            "description": "EXTENDED DELAYED DESCRIPTOR REPLICATION FACTOR", 
            "unit": "NUMERIC"
        }, 
        "B48149": {
            "description": "[SIM] Conta Chenopodiacee - Amarantacee Indistinte_Amaranto", 
            "unit": "NUMERIC"
        }, 
        "B48148": {
            "description": "[SIM] Conta Cupressacee - Taxacee indistinte_Cupressacee - TaxacNUMERIC", 
            "unit": "NUMERIC"
        }, 
        "B48184": {
            "description": "[SIM] Conta Ciperacee_Ciperacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48141": {
            "description": "[SIM] Conta Fagacee_Fagacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B22074": {
            "description": "AVERAGE WAVE PERIOD", 
            "unit": "S"
        }, 
        "B48143": {
            "description": "[SIM] Conta Oleacee_Frassino", 
            "unit": "NUMERIC"
        }, 
        "B48142": {
            "description": "[SIM] Conta Oleacee_Olivo", 
            "unit": "NUMERIC"
        }, 
        "B22071": {
            "description": "SPECTRAL PEAK WAVE PERIOD", 
            "unit": "S"
        }, 
        "B22070": {
            "description": "SIGNIFICANT WAVE HEIGHT", 
            "unit": "M"
        }, 
        "B48147": {
            "description": "[SIM] Conta Cupressacee - Taxacee indistinte_Cipresso comune", 
            "unit": "NUMERIC"
        }, 
        "B48146": {
            "description": "[SIM] Conta Urticacee_Urticacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B15204": {
            "description": "[SIM] PM06 Concentration (tot. aerosol < 0.6 ug)", 
            "unit": "KG/M**3"
        }, 
        "B15205": {
            "description": "[SIM] PM03 Concentration (tot. aerosol < 0.3 ug)", 
            "unit": "KG/M**3"
        }, 
        "B15206": {
            "description": "[SIM] PM015 Concentration (tot. aerosol < 0.15 ug)", 
            "unit": "KG/M**3"
        }, 
        "B15207": {
            "description": "[SIM] PM008 Concentration (tot. aerosol < 0.08 ug)", 
            "unit": "KG/M**3"
        }, 
        "B15200": {
            "description": "[SIM] HCNM Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15201": {
            "description": "[SIM] ALDE Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15202": {
            "description": "[SIM] PM5 Concentration (tot. aerosol < 5 ug)", 
            "unit": "KG/M**3"
        }, 
        "B15203": {
            "description": "[SIM] PM1 Concentration (tot. aerosol < 1.25 ug)", 
            "unit": "KG/M**3"
        }, 
        "B15208": {
            "description": "[SIM] Concentration of primary particulate matter in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15209": {
            "description": "[SIM] Concentration of sulfate in PM10", 
            "unit": "KG/M**3"
        }, 
        "B10063": {
            "description": "CHARACTERISTIC OF PRESSURE TENDENCY", 
            "unit": "CODE TABLE 10063"
        }, 
        "B10060": {
            "description": "PRESSURE CHANGE", 
            "unit": "PA"
        }, 
        "B22192": {
            "description": "[SIM] Current X component", 
            "unit": "M/S"
        }, 
        "B22193": {
            "description": "[SIM] Current Y component", 
            "unit": "M/S"
        }, 
        "B08208": {
            "description": "[SIM] Number of cloud cover mean values present", 
            "unit": "NUMERIC"
        }, 
        "B08209": {
            "description": "[SIM] Number of cloud cover maximum values present", 
            "unit": "NUMERIC"
        }, 
        "B08202": {
            "description": "[SIM] Number of mean pressure values present", 
            "unit": "NUMERIC"
        }, 
        "B08203": {
            "description": "[SIM] Number of minimum pressure values present", 
            "unit": "NUMERIC"
        }, 
        "B08200": {
            "description": "[SIM] Number of minimum relative humidity values present", 
            "unit": "NUMERIC"
        }, 
        "B08201": {
            "description": "[SIM] Number of maximum relative humidity values present", 
            "unit": "NUMERIC"
        }, 
        "B08206": {
            "description": "[SIM] Number of leaf wetness values present", 
            "unit": "NUMERIC"
        }, 
        "B08207": {
            "description": "[SIM] Number of scalar wind velocity mean values present", 
            "unit": "NUMERIC"
        }, 
        "B08204": {
            "description": "[SIM] Number of maximum pressure values present", 
            "unit": "NUMERIC"
        }, 
        "B08205": {
            "description": "[SIM] Number of precipitation values present", 
            "unit": "NUMERIC"
        }, 
        "B04004": {
            "description": "HOUR", 
            "unit": "HOUR"
        }, 
        "B04005": {
            "description": "MINUTE", 
            "unit": "MINUTE"
        }, 
        "B04006": {
            "description": "SECOND", 
            "unit": "SECOND"
        }, 
        "B04001": {
            "description": "YEAR", 
            "unit": "YEAR"
        }, 
        "B04002": {
            "description": "MONTH", 
            "unit": "MONTH"
        }, 
        "B04003": {
            "description": "DAY", 
            "unit": "DAY"
        }, 
        "B15213": {
            "description": "[SIM] Concentration of organic carbon in PM10", 
            "unit": "KG/M**3"
        }, 
        "B02004": {
            "description": "TYPE OF INSTRUMENTATION FOR EVAPORATION MEASUREMENT OR TYPE OF CCODE TABLE 2004", 
            "unit": "CODE TABLE 2004"
        }, 
        "B02005": {
            "description": "PRECISION OF TEMPERATURE OBSERVATION", 
            "unit": "K"
        }, 
        "B02002": {
            "description": "TYPE OF INSTRUMENTATION FOR WIND MEASUREMENT", 
            "unit": "FLAG TABLE 2002"
        }, 
        "B02003": {
            "description": "TYPE OF MEASURING EQUIPMENT USED", 
            "unit": "CODE TABLE 2003"
        }, 
        "B02001": {
            "description": "TYPE OF STATION", 
            "unit": "CODE TABLE 2001"
        }, 
        "B23193": {
            "description": "[SIM] Wet deposition of H2SO4", 
            "unit": "MOL/M**2"
        }, 
        "B23192": {
            "description": "[SIM] Dry deposition of H2SO4", 
            "unit": "MOL/M**2"
        }, 
        "B13192": {
            "description": "[SIM] Cloud liquid water content", 
            "unit": "KG/KG"
        }, 
        "B13193": {
            "description": "[SIM] Cloud ice content", 
            "unit": "KG/KG"
        }, 
        "B14199": {
            "description": "[SIM] Visible radiation (upward)", 
            "unit": "W/M**2"
        }, 
        "B14198": {
            "description": "[SIM] Visible radiation (downward)", 
            "unit": "W/M**2"
        }, 
        "B14193": {
            "description": "[SIM] Instantenous latent heat flux", 
            "unit": "W/m**2"
        }, 
        "B14192": {
            "description": "[SIM] Instantenous sensible heat flux", 
            "unit": "W/m**2"
        }, 
        "B20044": {
            "description": "AVERAGE LIQUID WATER CONTENT", 
            "unit": "KG/M**3"
        }, 
        "B20045": {
            "description": "SUPERCOOLED LARGE DROPLET (SLD) CONDITIONS", 
            "unit": "CODE TABLE 20045"
        }, 
        "B20042": {
            "description": "AIRFRAME ICING PRESENT", 
            "unit": "CODE TABLE 20042"
        }, 
        "B20043": {
            "description": "PEAK LIQUID WATER CONTENT", 
            "unit": "KG/M**3"
        }, 
        "B14195": {
            "description": "[SIM] Instantenous diffuse solar radiation", 
            "unit": "W/M**2"
        }, 
        "B14194": {
            "description": "[SIM] Instantenous direct solar radiation", 
            "unit": "W/M**2"
        }, 
        "B15219": {
            "description": "[SIM] Concentration of water in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15218": {
            "description": "[SIM] Concentration of biogenic BmP in PM10", 
            "unit": "KG/M**3"
        }, 
        "B48048": {
            "description": "[SIM] Graminacee_Graminacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48049": {
            "description": "[SIM] Plantaginacee_Plantaginacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B20038": {
            "description": "BEARING OF ICE EDGE (SEE NOTE 3)", 
            "unit": "DEGREE TRUE"
        }, 
        "B20033": {
            "description": "CAUSE OF ICE ACCRETION", 
            "unit": "FLAG TABLE 20033"
        }, 
        "B20032": {
            "description": "RATE OF ICE ACCRETION", 
            "unit": "CODE TABLE 20032"
        }, 
        "B20031": {
            "description": "ICE DEPOSIT (THICKNESS)", 
            "unit": "M"
        }, 
        "B48043": {
            "description": "[SIM] Spore fungine_Epicoccum", 
            "unit": "POLLEN/M**3"
        }, 
        "B20037": {
            "description": "ICE DEVELOPMENT", 
            "unit": "CODE TABLE 20037"
        }, 
        "B20036": {
            "description": "ICE SITUATION", 
            "unit": "CODE TABLE 20036"
        }, 
        "B20035": {
            "description": "AMOUNT AND TYPE OF ICE", 
            "unit": "CODE TABLE 20035"
        }, 
        "B20034": {
            "description": "SEA ICE CONCENTRATION", 
            "unit": "CODE TABLE 20034"
        }, 
        "B22031": {
            "description": "SPEED OF CURRENT", 
            "unit": "M/S"
        }, 
        "B22032": {
            "description": "SPEED OF SEA SURFACE CURRENT", 
            "unit": "M/S"
        }, 
        "B22037": {
            "description": "Tidal elevation with respect to national land datum", 
            "unit": "M"
        }, 
        "B48185": {
            "description": "[SIM] Conta Juglandacee_Juglandacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B22038": {
            "description": "Tidal elevation with respect to local chart datum", 
            "unit": "M"
        }, 
        "B48187": {
            "description": "[SIM] Conta Oleacee_Ligustro", 
            "unit": "NUMERIC"
        }, 
        "B48186": {
            "description": "[SIM] Conta Ippocastanacee_Ippocastanacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48181": {
            "description": "[SIM] Conta Platanacee_Platanacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48180": {
            "description": "[SIM] Conta Mirtacee_Mirtacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48183": {
            "description": "[SIM] Conta Pinacee_Pinacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48182": {
            "description": "[SIM] Conta Aceraceae_Aceracee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B05021": {
            "description": "BEARING OR AZIMUTH", 
            "unit": "DEGREE TRUE"
        }, 
        "B05022": {
            "description": "SOLAR AZIMUTH", 
            "unit": "DEGREE TRUE"
        }, 
        "B33015": {
            "description": "DATA QUALITY CHECK INDICATOR", 
            "unit": "CODE TABLE 33015"
        }, 
        "B33201": {
            "description": "[SIM] Kalman coefficient, state vector (s.v.) x1", 
            "unit": "NUMERIC"
        }, 
        "B33202": {
            "description": "[SIM] Kalman coefficient, state vector (s.v.) x2", 
            "unit": "NUMERIC"
        }, 
        "B33203": {
            "description": "[SIM] Kalman coefficient, s.v. error covariance matrix(1,1)", 
            "unit": "NUMERIC"
        }, 
        "B33204": {
            "description": "[SIM] Kalman coefficient, s.v. error covariance matrix(1,2)", 
            "unit": "NUMERIC"
        }, 
        "B33205": {
            "description": "[SIM] Kalman coefficient, s.v. error covariance matrix(2,1)", 
            "unit": "NUMERIC"
        }, 
        "B33206": {
            "description": "[SIM] Kalman coefficient, s.v. error covariance matrix(2,2)", 
            "unit": "NUMERIC"
        }, 
        "B33207": {
            "description": "[SIM] Kalman observation sequential counter", 
            "unit": "NUMERIC"
        }, 
        "B33208": {
            "description": "[SIM] Kalman osservation missing counter", 
            "unit": "NUMERIC"
        }, 
        "B33209": {
            "description": "[SIM] Normalized Density Index", 
            "unit": "%"
        }, 
        "B01194": {
            "description": "[SIM] Report mnemonic", 
            "unit": "CCITTIA5"
        }, 
        "B01193": {
            "description": "[SIM] Report code", 
            "unit": "NUMERIC"
        }, 
        "B01192": {
            "description": "[SIM] MeteoDB station ID", 
            "unit": "NUMERIC"
        }, 
        "B48130": {
            "description": "[SIM] Conta Betulacee_Betulla", 
            "unit": "NUMERIC"
        }, 
        "B48131": {
            "description": "[SIM] Conta Betulacee_Betulacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48132": {
            "description": "[SIM] Conta Composite_Ambrosia", 
            "unit": "NUMERIC"
        }, 
        "B48133": {
            "description": "[SIM] Conta Composite_Artemisia", 
            "unit": "NUMERIC"
        }, 
        "B48134": {
            "description": "[SIM] Conta Composite_Composite indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48135": {
            "description": "[SIM] Conta Corilacee_Nocciolo", 
            "unit": "NUMERIC"
        }, 
        "B48136": {
            "description": "[SIM] Conta Corilacee_Carpino bianco -Carpino nero", 
            "unit": "NUMERIC"
        }, 
        "B48137": {
            "description": "[SIM] Conta Corilacee_Corilacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48138": {
            "description": "[SIM] Conta Fagacee_Castagno", 
            "unit": "NUMERIC"
        }, 
        "B48139": {
            "description": "[SIM] Conta Fagacee_Faggio", 
            "unit": "NUMERIC"
        }, 
        "B12121": {
            "description": "GROUND MINIMUM TEMPERATURE", 
            "unit": "K"
        }, 
        "B48026": {
            "description": "[SIM] Mirtacee_Mirtacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B15212": {
            "description": "[SIM] Concentration of black carbon in PM10", 
            "unit": "KG/M**3"
        }, 
        "B48027": {
            "description": "[SIM] Ulmacee_Bagolaro comune", 
            "unit": "POLLEN/M**3"
        }, 
        "B02048": {
            "description": "SATELLITE SENSOR INDICATOR", 
            "unit": "CODE TABLE 2048"
        }, 
        "B10052": {
            "description": "ALTIMETER SETTING (QNH)", 
            "unit": "PA"
        }, 
        "B48028": {
            "description": "[SIM] Ulmacee_Olmo campestre", 
            "unit": "POLLEN/M**3"
        }, 
        "B10051": {
            "description": "PRESSURE REDUCED TO MEAN SEA LEVEL", 
            "unit": "PA"
        }, 
        "B48029": {
            "description": "[SIM] Ulmacee_Ulmacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B04196": {
            "description": "[SIM] Relative humidity event - time of occurrence", 
            "unit": "MINUTE"
        }, 
        "B04197": {
            "description": "[SIM] Wind velocity event - time of occurrence", 
            "unit": "MINUTE"
        }, 
        "B04194": {
            "description": "[SIM] Time range P2", 
            "unit": "NUMERIC"
        }, 
        "B04195": {
            "description": "[SIM] Temperature event - time of occurrence", 
            "unit": "MINUTE"
        }, 
        "B04192": {
            "description": "[SIM] Time range type", 
            "unit": "NUMERIC"
        }, 
        "B04193": {
            "description": "[SIM] Time range P1", 
            "unit": "NUMERIC"
        }, 
        "B04198": {
            "description": "[SIM] Pressure event - time of occurrence", 
            "unit": "MINUTE"
        }, 
        "B48008": {
            "description": "[SIM] Corilacee_Nocciolo", 
            "unit": "POLLEN/M**3"
        }, 
        "B48009": {
            "description": "[SIM] Corilacee_Carpino bianco -Carpino nero", 
            "unit": "POLLEN/M**3"
        }, 
        "B48004": {
            "description": "[SIM] Betulacee_Betulacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48005": {
            "description": "[SIM] Composite_Ambrosia", 
            "unit": "POLLEN/M**3"
        }, 
        "B48006": {
            "description": "[SIM] Composite_Artemisia", 
            "unit": "POLLEN/M**3"
        }, 
        "B48007": {
            "description": "[SIM] Composite_Composite indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48001": {
            "description": "[SIM] Graminacee_Graminacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48002": {
            "description": "[SIM] Betulacee_Ontano nero", 
            "unit": "POLLEN/M**3"
        }, 
        "B48003": {
            "description": "[SIM] Betulacee_Betulla", 
            "unit": "POLLEN/M**3"
        }, 
        "B01023": {
            "description": "OBSERVATION SEQUENCE NUMBER", 
            "unit": "NUMERIC"
        }, 
        "B11016": {
            "description": "EXTREME COUNTERCLOCKWISE WIND DIRECTION OF A VARIABLE WIND", 
            "unit": "DEGREE TRUE"
        }, 
        "B20003": {
            "description": "PRESENT WEATHER (SEE NOTE 1)", 
            "unit": "CODE TABLE 20003"
        }, 
        "B20001": {
            "description": "HORIZONTAL VISIBILITY", 
            "unit": "M"
        }, 
        "B20004": {
            "description": "PAST WEATHER (1) (SEE NOTE 2)", 
            "unit": "CODE TABLE 20004"
        }, 
        "B20005": {
            "description": "PAST WEATHER (2) (SEE NOTE 2)", 
            "unit": "CODE TABLE 20005"
        }, 
        "B20009": {
            "description": "GENERAL WEATHER INDICATOR (TAF/METAR)", 
            "unit": "CODE TABLE 20009"
        }, 
        "B13206": {
            "description": "[SIM] Soil water content", 
            "unit": "KG/M**2"
        }, 
        "B13204": {
            "description": "[SIM] Total convective precipitation (liquid + snow)", 
            "unit": "KG/M**2"
        }, 
        "B13205": {
            "description": "[SIM] Snowfall (grid-scale + convective)", 
            "unit": "KG/M**2"
        }, 
        "B13202": {
            "description": "[SIM] Convective liquid precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13203": {
            "description": "[SIM] Convective snowfall", 
            "unit": "KG/M**2"
        }, 
        "B13200": {
            "description": "[SIM] Grid-scale liquid precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13201": {
            "description": "[SIM] Grid-scale snowfall", 
            "unit": "KG/M**2"
        }, 
        "B48174": {
            "description": "[SIM] Conta Altre Spore / Non identificati_Spore fungine non ideNUMERIC", 
            "unit": "NUMERIC"
        }, 
        "B48175": {
            "description": "[SIM] Conta Graminacee_Graminacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48176": {
            "description": "[SIM] Conta Plantaginacee_Plantaginacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48177": {
            "description": "[SIM] Conta Urticacee_Urticacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B48170": {
            "description": "[SIM] Conta Spore fungine_Epicoccum", 
            "unit": "NUMERIC"
        }, 
        "B48171": {
            "description": "[SIM] Conta Altri Pollini / Non Identificati_Altri pollini identNUMERIC", 
            "unit": "NUMERIC"
        }, 
        "B48172": {
            "description": "[SIM] Conta Altri Pollini / Non Identificati_Pollini non identifNUMERIC", 
            "unit": "NUMERIC"
        }, 
        "B48173": {
            "description": "[SIM] Conta Altre Spore / Non identificati_Altre spore fungine", 
            "unit": "NUMERIC"
        }, 
        "B31012": {
            "description": "EXTENDED DELAYED DESCRIPTOR AND DATA REPETITION FACTOR", 
            "unit": "NUMERIC"
        }, 
        "B31011": {
            "description": "DELAYED DESCRIPTOR AND DATA REPETITION FACTOR", 
            "unit": "NUMERIC"
        }, 
        "B07030": {
            "description": "HEIGHT OF STATION GROUND ABOVE MEAN SEA LEVEL (SEE NOTE 3)", 
            "unit": "M"
        }, 
        "B07031": {
            "description": "HEIGHT OF BAROMETER ABOVE MEAN SEA LEVEL (SEE NOTE 4)", 
            "unit": "M"
        }, 
        "B07032": {
            "description": "HEIGHT OF SENSOR ABOVE LOCAL GROUND (OR DECK OF MARINE PLATFORM)M", 
            "unit": "M"
        }, 
        "B22049": {
            "description": "SEA-SURFACE TEMPERATURE", 
            "unit": "K"
        }, 
        "B12003": {
            "description": "DEW-POINT TEMPERATURE", 
            "unit": "K"
        }, 
        "B12001": {
            "description": "TEMPERATURE/AIR TEMPERATURE", 
            "unit": "K"
        }, 
        "B22043": {
            "description": "SEA/WATER TEMPERATURE", 
            "unit": "K"
        }, 
        "B07195": {
            "description": "[SIM] Second level type", 
            "unit": "NUMERIC"
        }, 
        "B07194": {
            "description": "[SIM] Level L2", 
            "unit": "NUMERIC"
        }, 
        "B07193": {
            "description": "[SIM] Level L1", 
            "unit": "NUMERIC"
        }, 
        "B07192": {
            "description": "[SIM] First level type", 
            "unit": "NUMERIC"
        }, 
        "B15198": {
            "description": "[SIM] PM2.5 Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15199": {
            "description": "[SIM] NOY Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15211": {
            "description": "[SIM] Concentration of ammonium in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15210": {
            "description": "[SIM] Concentration of nitrate in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15217": {
            "description": "[SIM] Concentration of biogenic A1D in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15216": {
            "description": "[SIM] Concentration of anthrop. BmP in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15215": {
            "description": "[SIM] Concentration of anthrop. A1D in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15214": {
            "description": "[SIM] Concentration of dust in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15192": {
            "description": "[SIM] NO Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15193": {
            "description": "[SIM] NO2 Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15194": {
            "description": "[SIM] O3 Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15195": {
            "description": "[SIM] PM10 Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15196": {
            "description": "[SIM] CO Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15197": {
            "description": "[SIM] SO2 Concentration", 
            "unit": "KG/M**3"
        }, 
        "B48145": {
            "description": "[SIM] Conta Plantaginacee_Plantaginacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48144": {
            "description": "[SIM] Conta Oleacee_Oleacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B08210": {
            "description": "[SIM] Number of cloud cover minimum values present", 
            "unit": "NUMERIC"
        }, 
        "B02014": {
            "description": "TRACKING TECHNIQUE/STATUS OF SYSTEM USED", 
            "unit": "CODE TABLE 2014"
        }, 
        "B02011": {
            "description": "RADIOSONDE TYPE", 
            "unit": "CODE TABLE 2011"
        }, 
        "B02013": {
            "description": "SOLAR AND INFRARED RADIATION CORRECTION", 
            "unit": "CODE TABLE 2013"
        }, 
        "B02012": {
            "description": "RADIOSONDE COMPUTATIONAL METHOD", 
            "unit": "CODE TABLE 2012"
        }, 
        "B33006": {
            "description": "INTERNAL MEASUREMENT STATUS INFORMATION (AWS)", 
            "unit": "CODE TABLE 33006"
        }, 
        "B04086": {
            "description": "LONG TIME PERIOD OR DISPLACEMENT", 
            "unit": "SECOND"
        }, 
        "B01002": {
            "description": "WMO STATION NUMBER", 
            "unit": "NUMERIC"
        }, 
        "B20194": {
            "description": "[SIM] Presence of shower", 
            "unit": "BOOLEAN"
        }, 
        "B20195": {
            "description": "[SIM] Presence of hail", 
            "unit": "BOOLEAN"
        }, 
        "B20196": {
            "description": "[SIM] Presence of thunderstorm", 
            "unit": "BOOLEAN"
        }, 
        "B20197": {
            "description": "[SIM] Presence of snow", 
            "unit": "BOOLEAN"
        }, 
        "B20192": {
            "description": "[SIM] Presence of rain > 1mm", 
            "unit": "BOOLEAN"
        }, 
        "B20193": {
            "description": "[SIM] Cloud type (METAR)", 
            "unit": "CCITTIA5"
        }, 
        "B06001": {
            "description": "LONGITUDE (HIGH ACCURACY)", 
            "unit": "DEGREE"
        }, 
        "B20198": {
            "description": "[SIM] Presence of frost", 
            "unit": "BOOLEAN"
        }, 
        "B20199": {
            "description": "[SIM] Presence of dew", 
            "unit": "BOOLEAN"
        }, 
        "B13031": {
            "description": "EVAPOTRANSPIRATION", 
            "unit": "KG/M**2"
        }, 
        "B13033": {
            "description": "EVAPORATION/EVAPOTRANSPIRATION", 
            "unit": "KG/M**2"
        }, 
        "B48057": {
            "description": "[SIM] Ciperacee_Ciperacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48056": {
            "description": "[SIM] Pinacee_Pinacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48055": {
            "description": "[SIM] Aceraceae_Aceracee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48054": {
            "description": "[SIM] Platanacee_Platanacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48053": {
            "description": "[SIM] Mirtacee_Mirtacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48052": {
            "description": "[SIM] Euphorbiacee_Euforbiacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48051": {
            "description": "[SIM] Poligonacee_Poligonacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48050": {
            "description": "[SIM] Urticacee_Urticacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48059": {
            "description": "[SIM] Ippocastanacee_Ippocastanacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B48058": {
            "description": "[SIM] Juglandacee_Juglandacee indistinte 1", 
            "unit": "POLLEN/M**3"
        }, 
        "B11208": {
            "description": "[SIM] Distance covered by the hourly mean wind", 
            "unit": "M"
        }, 
        "B25076": {
            "description": "LOG-10 OF (TEMP-RAD CENTRAL WAVENUMBER) FOR ATOVS", 
            "unit": "LOGM-1"
        }, 
        "B02070": {
            "description": "ORIGINAL SPECIFICATION OF LATITUDE/LONGITUDE", 
            "unit": "CODE TABLE 2070"
        }, 
        "B48045": {
            "description": "[SIM] Altri Pollini / Non Identificati_Pollini non identificati", 
            "unit": "POLLEN/M**3"
        }, 
        "B11200": {
            "description": "[SIM] U-component of momentum flux", 
            "unit": "N/M**2"
        }, 
        "B11201": {
            "description": "[SIM] V-component of momentum flux", 
            "unit": "N/M**2"
        }, 
        "B11202": {
            "description": "[SIM] Friction velocity (diagmet)", 
            "unit": "M/S"
        }, 
        "B11203": {
            "description": "[SIM] Mixing height (diagmet)", 
            "unit": "M"
        }, 
        "B11204": {
            "description": "[SIM] Obukov lenght (diagmet)", 
            "unit": "M"
        }, 
        "B11205": {
            "description": "[SIM] Convective velocitiy scale (diagmet)", 
            "unit": "M/S"
        }, 
        "B11206": {
            "description": "[SIM] Friction velocity (COSMO)", 
            "unit": "M/S"
        }, 
        "B11207": {
            "description": "[SIM] Obukov lenght (COSMO)", 
            "unit": "M"
        }, 
        "B11061": {
            "description": "ABSOLUTE WIND SHEAR IN 1 KM LAYER BELOW", 
            "unit": "M/S"
        }, 
        "B11062": {
            "description": "ABSOLUTE WIND SHEAR IN 1 KM LAYER ABOVE", 
            "unit": "M/S"
        }, 
        "B08009": {
            "description": "DETAILED PHASE OF FLIGHT", 
            "unit": "CODE TABLE 8009"
        }, 
        "B08002": {
            "description": "VERTICAL SIGNIFICANCE (SURFACE OBSERVATIONS)", 
            "unit": "CODE TABLE 8002"
        }, 
        "B08004": {
            "description": "PHASE OF AIRCRAFT FLIGHT", 
            "unit": "CODE TABLE 8004"
        }, 
        "B22001": {
            "description": "DIRECTION OF WAVES", 
            "unit": "DEGREE TRUE"
        }, 
        "B22002": {
            "description": "DIRECTION OF WIND WAVES", 
            "unit": "DEGREE TRUE"
        }, 
        "B22003": {
            "description": "DIRECTION OF SWELL WAVES", 
            "unit": "DEGREE TRUE"
        }, 
        "B01063": {
            "description": "ICAO LOCATION INDICATOR", 
            "unit": "CCITTIA5"
        }, 
        "B33024": {
            "description": "STATION ELEVATION QUALITY MARK (FOR MOBILE STATIONS)", 
            "unit": "CODE TABLE 33024"
        }, 
        "B33025": {
            "description": "ACARS INTERPOLATED VALUES", 
            "unit": "CODE TABLE 33025"
        }, 
        "B33026": {
            "description": "MOISTURE QUALITY", 
            "unit": "CODE TABLE 33026"
        }, 
        "B33027": {
            "description": "LOCATION QUALITY CLASS (RANGE OF RADIUS OF 66 % CONFIDENCE)", 
            "unit": "CODE TABLE 33027"
        }, 
        "B33020": {
            "description": "QUALITY CONTROL INDICATION OF FOLLOWING VALUE", 
            "unit": "CODE TABLE 33020"
        }, 
        "B33021": {
            "description": "QUALITY OF FOLLOWING VALUE", 
            "unit": "CODE TABLE 33021"
        }, 
        "B33022": {
            "description": "QUALITY OF BUOY SATELLITE TRANSMISSION", 
            "unit": "CODE TABLE 33022"
        }, 
        "B33023": {
            "description": "QUALITY OF BUOY LOCATION", 
            "unit": "CODE TABLE 33023"
        }, 
        "B48178": {
            "description": "[SIM] Conta Poligonacee_Poligonacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B33031": {
            "description": "SCAN LINE QUALITY FLAGS FOR ATOVS", 
            "unit": "FLAG TABLE 33031"
        }, 
        "B48179": {
            "description": "[SIM] Conta Euphorbiacee_Euforbiacee indistinte 1", 
            "unit": "NUMERIC"
        }, 
        "B31021": {
            "description": "ASSOCIATED FIELD SIGNIFICANCE", 
            "unit": "CODE TABLE 31021"
        }, 
        "B12030": {
            "description": "SOIL TEMPERATURE", 
            "unit": "K"
        }, 
        "B33003": {
            "description": "QUALITY INFORMATION", 
            "unit": "CODE TABLE 33003"
        }, 
        "B48129": {
            "description": "[SIM] Conta Betulacee_Ontano nero", 
            "unit": "NUMERIC"
        }, 
        "B48128": {
            "description": "[SIM] Conta Graminacee_Graminacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B12131": {
            "description": "SNOW TEMPERATURE", 
            "unit": "K"
        }, 
        "B15228": {
            "description": "[SIM] NH3 Concentration", 
            "unit": "KG/M**3"
        }, 
        "B15229": {
            "description": "[SIM] Concentration of primary part. matter in aerosol", 
            "unit": "KG/M**3"
        }, 
        "B15222": {
            "description": "[SIM] Total concentration of primary aerosol in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15223": {
            "description": "[SIM] Total concentration of secondary aerosol in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15220": {
            "description": "[SIM] Concentration of sea salt in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15221": {
            "description": "[SIM] Concentration of secondary organic aerosol in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15226": {
            "description": "[SIM] Uncertainity in NO2 estimate (Pesco)", 
            "unit": "KG/M**3"
        }, 
        "B15227": {
            "description": "[SIM] Uncertainity in PM2.5 estimate (Pesco)", 
            "unit": "KG/M**3"
        }, 
        "B15224": {
            "description": "[SIM] Uncertainity in O3 estimate (Pesco)", 
            "unit": "KG/M**3"
        }, 
        "B15225": {
            "description": "[SIM] Uncertainity in PM10 estimate (Pesco)", 
            "unit": "KG/M**3"
        }, 
        "B48019": {
            "description": "[SIM] Urticacee_Urticacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48018": {
            "description": "[SIM] Plantaginacee_Plantaginacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48013": {
            "description": "[SIM] Fagacee_Quercia", 
            "unit": "POLLEN/M**3"
        }, 
        "B48012": {
            "description": "[SIM] Fagacee_Faggio", 
            "unit": "POLLEN/M**3"
        }, 
        "B48011": {
            "description": "[SIM] Fagacee_Castagno", 
            "unit": "POLLEN/M**3"
        }, 
        "B48010": {
            "description": "[SIM] Corilacee_Corilacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48017": {
            "description": "[SIM] Oleacee_Oleacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48016": {
            "description": "[SIM] Oleacee_Frassino", 
            "unit": "POLLEN/M**3"
        }, 
        "B48015": {
            "description": "[SIM] Oleacee_Olivo", 
            "unit": "POLLEN/M**3"
        }, 
        "B48014": {
            "description": "[SIM] Fagacee_Fagacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B01019": {
            "description": "LONG STATION OR SITE NAME", 
            "unit": "CCITTIA5"
        }, 
        "B01011": {
            "description": "SHIP OR MOBILE LAND STATION IDENTIFIER", 
            "unit": "CCITTIA5"
        }, 
        "B01012": {
            "description": "DIRECTION OF MOTION OF MOVING OBSERVING PLATFORM**", 
            "unit": "DEGREE TRUE"
        }, 
        "B01013": {
            "description": "SPEED OF MOTION OF MOVING OBSERVING PLATFORM*", 
            "unit": "M/S"
        }, 
        "B08044": {
            "description": "(VAL) CAS REGISTRY NUMBER", 
            "unit": "CCITTIA5"
        }, 
        "B14031": {
            "description": "TOTAL SUNSHINE", 
            "unit": "MINUTE"
        }, 
        "B08042": {
            "description": "EXTENDED VERTICAL SOUNDING SIGNIFICANCE", 
            "unit": "FLAG TABLE 8042"
        }, 
        "B20011": {
            "description": "CLOUD AMOUNT", 
            "unit": "CODE TABLE 20011"
        }, 
        "B20010": {
            "description": "CLOUD COVER (TOTAL)", 
            "unit": "%"
        }, 
        "B20013": {
            "description": "HEIGHT OF BASE OF CLOUD", 
            "unit": "M"
        }, 
        "B20012": {
            "description": "CLOUD TYPE", 
            "unit": "CODE TABLE 20012"
        }, 
        "B20017": {
            "description": "CLOUD TOP DESCRIPTION", 
            "unit": "CODE TABLE 20017"
        }, 
        "B20019": {
            "description": "SIGNIFICANT PRESENT OR FORECAST WEATHER", 
            "unit": "CCITTIA5"
        }, 
        "B48060": {
            "description": "[SIM] Oleacee_Ligustro", 
            "unit": "POLLEN/M**3"
        }, 
        "B20200": {
            "description": "[SIM] Presence of fog", 
            "unit": "BOOLEAN"
        }, 
        "B20201": {
            "description": "[SIM] Presence of water-spout", 
            "unit": "BOOLEAN"
        }, 
        "B20202": {
            "description": "[SIM] State of the ground with snow", 
            "unit": "CODE TABLE"
        }, 
        "B12061": {
            "description": "SKIN TEMPERATURE", 
            "unit": "K"
        }, 
        "B12063": {
            "description": "BRIGHTNESS TEMPERATURE", 
            "unit": "K"
        }, 
        "B13215": {
            "description": "[SIM] River level", 
            "unit": "M"
        }, 
        "B13217": {
            "description": "[SIM] 5 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13216": {
            "description": "[SIM] Hourly precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13210": {
            "description": "[SIM] Penetration of the probe in the snow", 
            "unit": "M"
        }, 
        "B13212": {
            "description": "[SIM] Leaf wetness duration", 
            "unit": "S"
        }, 
        "B13219": {
            "description": "[SIM] 15 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13218": {
            "description": "[SIM] 10 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B48163": {
            "description": "[SIM] Conta Ciperacee_Ciperacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48162": {
            "description": "[SIM] Conta Salicacee_Salicacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48161": {
            "description": "[SIM] Conta Salicacee_Pioppo", 
            "unit": "NUMERIC"
        }, 
        "B48160": {
            "description": "[SIM] Conta Salicacee_Salice comune", 
            "unit": "NUMERIC"
        }, 
        "B48167": {
            "description": "[SIM] Conta Spore fungine_Botrytis", 
            "unit": "NUMERIC"
        }, 
        "B48166": {
            "description": "[SIM] Conta Spore fungine_Alternaria", 
            "unit": "NUMERIC"
        }, 
        "B48165": {
            "description": "[SIM] Conta Ippocastanacee_Ippocastanacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48164": {
            "description": "[SIM] Conta Juglandacee_Juglandacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48169": {
            "description": "[SIM] Conta Spore fungine_Cladosporium", 
            "unit": "NUMERIC"
        }, 
        "B48168": {
            "description": "[SIM] Conta Spore fungine_Stemphylium", 
            "unit": "NUMERIC"
        }, 
        "B07025": {
            "description": "SOLAR ZENITH ANGLE", 
            "unit": "DEGREE"
        }, 
        "B07024": {
            "description": "SATELLITE ZENITH ANGLE", 
            "unit": "DEGREE"
        }, 
        "B08198": {
            "description": "[SIM] Number of maximum temperature values present", 
            "unit": "NUMERIC"
        }, 
        "B08199": {
            "description": "[SIM] Number of mean relative humidity values present", 
            "unit": "NUMERIC"
        }, 
        "B05043": {
            "description": "FIELD OF VIEW NUMBER", 
            "unit": "NUMERIC"
        }, 
        "B05041": {
            "description": "SCAN LINE NUMBER", 
            "unit": "NUMERIC"
        }, 
        "B05040": {
            "description": "ORBIT NUMBER", 
            "unit": "NUMERIC"
        }, 
        "B08192": {
            "description": "[SIM] Number of wind velocity mean values present", 
            "unit": "NUMERIC"
        }, 
        "B08193": {
            "description": "[SIM] Number of wind velocity minimum values present", 
            "unit": "NUMERIC"
        }, 
        "B08196": {
            "description": "[SIM] Number of mean temperature values present", 
            "unit": "NUMERIC"
        }, 
        "B08197": {
            "description": "[SIM] Number of minimum temperature values present", 
            "unit": "NUMERIC"
        }, 
        "B08194": {
            "description": "[SIM] Number of wind velocity maximum values present", 
            "unit": "NUMERIC"
        }, 
        "B08195": {
            "description": "[SIM] Number of wind prevalent direction values present", 
            "unit": "NUMERIC"
        }, 
        "B12193": {
            "description": "PSEUDO-EQUIVALENT POTENTIAL TEMPERATURE", 
            "unit": "K"
        }, 
        "B12192": {
            "description": "POTENTIAL TEMPERATURE", 
            "unit": "K"
        }, 
        "B10004": {
            "description": "PRESSURE", 
            "unit": "PA"
        }, 
        "B10007": {
            "description": "HEIGHT", 
            "unit": "M"
        }, 
        "B10009": {
            "description": "GEOPOTENTIAL HEIGHT", 
            "unit": "GPM"
        }, 
        "B10008": {
            "description": "GEOPOTENTIAL", 
            "unit": "M**2/S**2"
        }, 
        "B12102": {
            "description": "WET-BULB TEMPERATURE", 
            "unit": "K"
        }, 
        "B12103": {
            "description": "DEW-POINT TEMPERATURE", 
            "unit": "K"
        }, 
        "B12101": {
            "description": "TEMPERATURE/DRY-BULB TEMPERATURE", 
            "unit": "K"
        }, 
        "B05015": {
            "description": "LATITUDE DISPLACEMENT (HIGH ACCURACY)", 
            "unit": "DEGREE"
        }, 
        "B13001": {
            "description": "SPECIFIC HUMIDITY", 
            "unit": "KG/KG"
        }, 
        "B13002": {
            "description": "MIXING RATIO", 
            "unit": "KG/KG"
        }, 
        "B13003": {
            "description": "RELATIVE HUMIDITY", 
            "unit": "%"
        }, 
        "B20062": {
            "description": "STATE OF THE GROUND (WITH OR WITHOUT SNOW)", 
            "unit": "CODE TABLE 20062"
        }, 
        "B06015": {
            "description": "LONGITUDE DISPLACEMENT (HIGH ACCURACY)", 
            "unit": "DEGREE"
        }, 
        "B48022": {
            "description": "[SIM] Chenopodiacee - Amarantacee Indistinte_Amaranto", 
            "unit": "POLLEN/M**3"
        }, 
        "B48023": {
            "description": "[SIM] Chenopodiacee - Amarantacee Indistinte_Chenopodiacee - AmaPOLLEN/M**3", 
            "unit": "POLLEN/M**3"
        }, 
        "B48020": {
            "description": "[SIM] Cupressacee - Taxacee indistinte_Cipresso comune", 
            "unit": "POLLEN/M**3"
        }, 
        "B48021": {
            "description": "[SIM] Cupressacee - Taxacee indistinte_Cupressacee - Taxacee indPOLLEN/M**3", 
            "unit": "POLLEN/M**3"
        }, 
        "B11198": {
            "description": "[SIM] SQRT(2*TKE)", 
            "unit": "M/S"
        }, 
        "B11199": {
            "description": "[SIM] Surface Roughness", 
            "unit": "M"
        }, 
        "B48024": {
            "description": "[SIM] Poligonacee_Poligonacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48025": {
            "description": "[SIM] Euphorbiacee_Euforbiacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B11194": {
            "description": "[SIM] Friction velocity (calmet)", 
            "unit": "M/S"
        }, 
        "B11195": {
            "description": "[SIM] Mixing height (calmet)", 
            "unit": "M"
        }, 
        "B11196": {
            "description": "[SIM] Obukov lenght (calmet)", 
            "unit": "M"
        }, 
        "B11197": {
            "description": "[SIM] Convective velocitiy scale (calmet)", 
            "unit": "M/S"
        }, 
        "B11192": {
            "description": "[SIM] W-component terrain following", 
            "unit": "M/S"
        }, 
        "B11193": {
            "description": "[SIM] Stability class", 
            "unit": "NUMERIC"
        }, 
        "B11077": {
            "description": "REPORTING INTERVAL OR AVERAGING TIME FOR EDDY DISSIPATION RATE", 
            "unit": "S"
        }, 
        "B11076": {
            "description": "PEAK TURBULENCE INTENSITY (EDDY DISSIPATION RATE)", 
            "unit": "M**(2/3)/S"
        }, 
        "B11075": {
            "description": "MEAN TURBULENCE INTENSITY (EDDY DISSIPATION RATE)", 
            "unit": "M**(2/3)/S"
        }, 
        "B33040": {
            "description": "CONFIDENCE INTERVAL", 
            "unit": "%"
        }, 
        "B33041": {
            "description": "ATTRIBUTE OF FOLLOWING VALUE", 
            "unit": "CODE TABLE 33041"
        }, 
        "B11017": {
            "description": "EXTREME CLOCKWISE WIND DIRECTION OF A VARIABLE WIND", 
            "unit": "DEGREE TRUE"
        }, 
        "B22013": {
            "description": "PERIOD OF SWELL WAVES", 
            "unit": "S"
        }, 
        "B22012": {
            "description": "PERIOD OF WIND WAVES", 
            "unit": "S"
        }, 
        "B22011": {
            "description": "PERIOD OF WAVES", 
            "unit": "S"
        }, 
        "B33038": {
            "description": "QUALITY FLAGS FOR GROUND-BASED GNSS DATA", 
            "unit": "FLAG TABLE 33038"
        }, 
        "B33033": {
            "description": "FIELD OF VIEW QUALITY FLAGS FOR ATOVS", 
            "unit": "FLAG TABLE 33033"
        }, 
        "B33032": {
            "description": "CHANNEL QUALITY FLAGS FOR ATOVS", 
            "unit": "FLAG TABLE 33032"
        }, 
        "B05001": {
            "description": "LATITUDE (HIGH ACCURACY)", 
            "unit": "DEGREE"
        }, 
        "B33030": {
            "description": "SCAN LINE STATUS FLAGS FOR ATOVS", 
            "unit": "FLAG TABLE 33030"
        }, 
        "B33037": {
            "description": "WIND CORRELATION ERROR", 
            "unit": "FLAG TABLE 33037"
        }, 
        "B33036": {
            "description": "NOMINAL CONFIDENCE THRESHOLD", 
            "unit": "%"
        }, 
        "B33035": {
            "description": "MANUAL/AUTOMATIC QUALITY CONTROL", 
            "unit": "CODE TABLE 33035"
        }, 
        "B31031": {
            "description": "DATA PRESENT INDICATOR", 
            "unit": "FLAG TABLE 31031"
        }, 
        "B07010": {
            "description": "FLIGHT LEVEL", 
            "unit": "M"
        }, 
        "B48158": {
            "description": "[SIM] Conta Aceraceae_Aceracee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48159": {
            "description": "[SIM] Conta Pinacee_Pinacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48152": {
            "description": "[SIM] Conta Euphorbiacee_Euforbiacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48153": {
            "description": "[SIM] Conta Mirtacee_Mirtacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48150": {
            "description": "[SIM] Conta Chenopodiacee - Amarantacee Indistinte_ChenopodiaceeNUMERIC", 
            "unit": "NUMERIC"
        }, 
        "B48151": {
            "description": "[SIM] Conta Poligonacee_Poligonacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48156": {
            "description": "[SIM] Conta Ulmacee_Ulmacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48157": {
            "description": "[SIM] Conta Platanacee_Platanacee indistinte", 
            "unit": "NUMERIC"
        }, 
        "B48154": {
            "description": "[SIM] Conta Ulmacee_Bagolaro comune", 
            "unit": "NUMERIC"
        }, 
        "B48155": {
            "description": "[SIM] Conta Ulmacee_Olmo campestre", 
            "unit": "NUMERIC"
        }, 
        "B14197": {
            "description": "[SIM] INSTANTANEOUS NET SHORT-WAVE RADIATION", 
            "unit": "W/M**2"
        }, 
        "B14196": {
            "description": "[SIM] INSTANTANEOUS NET LONG-WAVE RADIATION", 
            "unit": "W/M**2"
        }, 
        "B02064": {
            "description": "AIRCRAFT ROLL ANGLE QUALITY", 
            "unit": "CODE TABLE 2064"
        }, 
        "B02061": {
            "description": "AIRCRAFT NAVIGATIONAL SYSTEM", 
            "unit": "CODE TABLE 2061"
        }, 
        "B02062": {
            "description": "TYPE OF AIRCRAFT DATA RELAY SYSTEM", 
            "unit": "CODE TABLE 2062"
        }, 
        "B02063": {
            "description": "AIRCRAFT ROLL ANGLE", 
            "unit": "DEGREE"
        }, 
        "B15231": {
            "description": "[SIM] Concentration of nitrate in aerosol", 
            "unit": "KG/M**3"
        }, 
        "B15230": {
            "description": "[SIM] Concentration of sulfate in aerosol", 
            "unit": "KG/M**3"
        }, 
        "B15233": {
            "description": "[SIM] Concentration of anthrop. sec. org. in aerosol", 
            "unit": "KG/M**3"
        }, 
        "B15232": {
            "description": "[SIM] Concentration of ammonium in aerosol", 
            "unit": "KG/M**3"
        }, 
        "B15235": {
            "description": "[SIM] Concentration of ISOPA1 in PM10", 
            "unit": "KG/M**3"
        }, 
        "B15234": {
            "description": "[SIM] Concentration of biogenic sec. org. in aerosol", 
            "unit": "KG/M**3"
        }, 
        "B15236": {
            "description": "[SIM] C6H6 Concentration", 
            "unit": "KG/M**3"
        }, 
        "B14021": {
            "description": "GLOBAL SOLAR RADIATION, INTEGRATED OVER PERIOD SPECIFIED", 
            "unit": "J/M**2"
        }, 
        "B13196": {
            "description": "[SIM] Precipitating ice", 
            "unit": "KG/KG"
        }, 
        "B13197": {
            "description": "[SIM] Total precipitating water+ice", 
            "unit": "KG/KG"
        }, 
        "B13194": {
            "description": "[SIM] Water table depth", 
            "unit": "M"
        }, 
        "B13195": {
            "description": "[SIM] Precipitating liquid water", 
            "unit": "KG/KG"
        }, 
        "B23195": {
            "description": "[SIM] Wet deposition of NH4", 
            "unit": "MOL/M**2"
        }, 
        "B23194": {
            "description": "[SIM] Dry deposition of NH4", 
            "unit": "MOL/M**2"
        }, 
        "B23197": {
            "description": "[SIM] Wet deposition of HNO3", 
            "unit": "MOL/M**2"
        }, 
        "B23196": {
            "description": "[SIM] Dry deposition of HNO3", 
            "unit": "MOL/M**2"
        }, 
        "B23198": {
            "description": "[SIM] Solid transport by river", 
            "unit": "KG/S"
        }, 
        "B13198": {
            "description": "[SIM] Total liquid water (cloud+precipitating)", 
            "unit": "KG/KG"
        }, 
        "B13199": {
            "description": "[SIM] Total ice (cloud+precipitating)", 
            "unit": "KG/KG"
        }, 
        "B20021": {
            "description": "TYPE OF PRECIPITATION", 
            "unit": "FLAG TABLE 20021"
        }, 
        "B11043": {
            "description": "MAXIMUM WIND GUST DIRECTION", 
            "unit": "DEGREE TRUE"
        }, 
        "B11041": {
            "description": "MAXIMUM WIND GUST SPEED", 
            "unit": "M/S"
        }, 
        "B13220": {
            "description": "[SIM] 20 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13221": {
            "description": "[SIM] 30 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13222": {
            "description": "[SIM] 180 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13223": {
            "description": "[SIM] 360 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13224": {
            "description": "[SIM] 720 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13225": {
            "description": "[SIM] 1440 minutes precipitation", 
            "unit": "KG/M**2"
        }, 
        "B13226": {
            "description": "[SIM] River discharge", 
            "unit": "M**3/S"
        }, 
        "B13227": {
            "description": "[SIM] Soil volumetric water content", 
            "unit": "%"
        }, 
        "B13228": {
            "description": "[SIM] Piezometric level", 
            "unit": "M"
        }, 
        "B13229": {
            "description": "[SIM] Density of snow", 
            "unit": "KG/M**3"
        }, 
        "B22022": {
            "description": "HEIGHT OF WIND WAVES", 
            "unit": "M"
        }, 
        "B22023": {
            "description": "HEIGHT OF SWELL WAVES", 
            "unit": "M"
        }, 
        "B22021": {
            "description": "HEIGHT OF WAVES", 
            "unit": "M"
        }, 
        "B08021": {
            "description": "TIME SIGNIFICANCE", 
            "unit": "CODE TABLE 8021"
        }, 
        "B01007": {
            "description": "SATELLITE IDENTIFIER", 
            "unit": "CODE TABLE 1007"
        }, 
        "B01006": {
            "description": "AIRCRAFT FLIGHT NUMBER", 
            "unit": "CCITTIA5"
        }, 
        "B11031": {
            "description": "DEGREE OF TURBULENCE", 
            "unit": "CODE TABLE 11031"
        }, 
        "B11037": {
            "description": "TURBULENCE INDEX", 
            "unit": "CODE TABLE 11037"
        }, 
        "B33007": {
            "description": "PER CENT CONFIDENCE", 
            "unit": "%"
        }, 
        "B01001": {
            "description": "WMO BLOCK NUMBER", 
            "unit": "NUMERIC"
        }, 
        "B33005": {
            "description": "QUALITY INFORMATION (AWS DATA)", 
            "unit": "FLAG TABLE 33005"
        }, 
        "B11039": {
            "description": "EXTENDED TIME OF OCCURRENCE OF PEAK  EDDY DISSIPATION RATE", 
            "unit": "CODE TABLE 11039"
        }, 
        "B01008": {
            "description": "AIRCRAFT REGISTRATION NUMBER OR OTHER IDENTIFICATION", 
            "unit": "CCITTIA5"
        }, 
        "B01216": {
            "description": "AIR QUALITY OBSERVING STATION AREA TYPE", 
            "unit": "CODE TABLE 001216"
        }, 
        "B01217": {
            "description": "AIR QUALITY OBSERVING STATION TERRAIN TYPE", 
            "unit": "CODE TABLE 001217"
        }, 
        "B01214": {
            "description": "GEMS AIR QUALITY OBSERVING STATION CODE", 
            "unit": "CCITTIA5"
        }, 
        "B01215": {
            "description": "AIR QUALITY OBSERVING STATION DOMINANT EMISSION SOURCE", 
            "unit": "CODE TABLE 001215"
        }, 
        "B01212": {
            "description": "AIR QUALITY OBSERVING STATION LOCAL CODE", 
            "unit": "CCITTIA5"
        }, 
        "B01213": {
            "description": "AIRBASE AIR QUALITY OBSERVING STATION CODE", 
            "unit": "CCITTIA5"
        }, 
        "B48040": {
            "description": "[SIM] Spore fungine_Botrytis", 
            "unit": "POLLEN/M**3"
        }, 
        "B48041": {
            "description": "[SIM] Spore fungine_Stemphylium", 
            "unit": "POLLEN/M**3"
        }, 
        "B48042": {
            "description": "[SIM] Spore fungine_Cladosporium", 
            "unit": "POLLEN/M**3"
        }, 
        "B48044": {
            "description": "[SIM] Altri Pollini / Non Identificati_Altri pollini identificatPOLLEN/M**3", 
            "unit": "POLLEN/M**3"
        }, 
        "B14201": {
            "description": "[SIM] Infrared radiation (upward)", 
            "unit": "W/M**2"
        }, 
        "B14200": {
            "description": "[SIM] Infrared radiation (downward)", 
            "unit": "W/M**2"
        }, 
        "B48046": {
            "description": "[SIM] Altre Spore / Non identificati_Altre spore fungine", 
            "unit": "POLLEN/M**3"
        }, 
        "B48047": {
            "description": "[SIM] Altre Spore / Non identificati_Spore fungine non identificPOLLEN/M**3", 
            "unit": "POLLEN/M**3"
        }, 
        "B10197": {
            "description": "ANEMOMETER HEIGHT", 
            "unit": "M"
        }, 
        "B02039": {
            "description": "METHOD OF WET-BULB TEMPERATURE MEASUREMENT", 
            "unit": "CODE TABLE 2039"
        }, 
        "B02038": {
            "description": "METHOD OF WATER TEMPERATURE AND/OR SALINITY MEASUREMENT", 
            "unit": "CODE TABLE 2038"
        }, 
        "B48140": {
            "description": "[SIM] Conta Fagacee_Quercia", 
            "unit": "NUMERIC"
        }, 
        "B13013": {
            "description": "TOTAL SNOW DEPTH", 
            "unit": "M"
        }, 
        "B13012": {
            "description": "DEPTH OF FRESH SNOW", 
            "unit": "M"
        }, 
        "B13011": {
            "description": "TOTAL PRECIPITATION / TOTAL WATER EQUIVALENT", 
            "unit": "KG/M**2"
        }, 
        "B33002": {
            "description": "QUALITY INFORMATION", 
            "unit": "CODE TABLE 33002"
        }, 
        "B48031": {
            "description": "[SIM] Aceraceae_Aceracee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48030": {
            "description": "[SIM] Platanacee_Platanacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48033": {
            "description": "[SIM] Salicacee_Salice comune", 
            "unit": "POLLEN/M**3"
        }, 
        "B48032": {
            "description": "[SIM] Pinacee_Pinacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48035": {
            "description": "[SIM] Salicacee_Salicacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48034": {
            "description": "[SIM] Salicacee_Pioppo", 
            "unit": "POLLEN/M**3"
        }, 
        "B48037": {
            "description": "[SIM] Juglandacee_Juglandacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48036": {
            "description": "[SIM] Ciperacee_Ciperacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B48039": {
            "description": "[SIM] Spore fungine_Alternaria", 
            "unit": "POLLEN/M**3"
        }, 
        "B48038": {
            "description": "[SIM] Ippocastanacee_Ippocastanacee indistinte", 
            "unit": "POLLEN/M**3"
        }, 
        "B29192": {
            "description": "[SIM] Land fraction", 
            "unit": "%"
        }, 
        "B13081": {
            "description": "WATER CONDUCTIVITY", 
            "unit": "S/M"
        }, 
        "B13082": {
            "description": "WATER TEMPERATURE", 
            "unit": "K"
        }
    };
    this.borinud = this.borinud || {}
    $.extend(true, this.borinud, {
        config: {
            B: B
        }
    });
}());
